==> haskell-configurator-pg-0.2.5-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.5
visibility:           public
id:                   configurator-pg-0.2.5-BwrRjDaOPaQLva8IjCQnin
key:                  configurator-pg-0.2.5-BwrRjDaOPaQLva8IjCQnin
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  d50f2c5a95a8eaaf3dd086c03468b8e8
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/configurator-pg-0.2.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/configurator-pg-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/configurator-pg-0.2.5
hs-libraries:         HSconfigurator-pg-0.2.5-BwrRjDaOPaQLva8IjCQnin
depends:
    base-4.15.0.0 containers-0.6.4.1
    megaparsec-9.2.0-4jOz50swwTdC1OkC7cXk5Y
    protolude-0.3.0-DadyjsAgkzo8Jpxke6KwZB
    scientific-0.3.7.0-LvVousZ2ZB29j7oXDdeCGV text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.5-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.5
visibility:           public
id:                   configurator-pg-0.2.5-FC7Eq34pIid7QV9owZNHGZ
key:                  configurator-pg-0.2.5-FC7Eq34pIid7QV9owZNHGZ
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  40d258aab8dda7b0859e8c1e3bfa41c1
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/configurator-pg-0.2.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/configurator-pg-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/configurator-pg-0.2.5
hs-libraries:         HSconfigurator-pg-0.2.5-FC7Eq34pIid7QV9owZNHGZ
depends:
    base-4.15.0.0 containers-0.6.4.1
    megaparsec-9.2.0-LDByiSVjBO1EnZacitxvZW
    protolude-0.3.0-CQgAV7h0uRuIyfj2hgw7Y1
    scientific-0.3.7.0-80Xt5iXHAGIBd7njyVx1yZ text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
